@@ -5,19 +5,28 @@ pub enum TreeType {
     Input,
 }
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, PartialEq)]
 pub struct SyntaxTree {
     pub node: String,
     pub tree_type: TreeType,
     pub childs: Vec<SyntaxTree>,
+    pub tree_val_type: TreeValueType,
+}
+
+#[derive(Debug, Clone, PartialEq)]
+pub enum TreeValueType {
+    String,
+    Integer,
+    Nil
 }
 
 impl SyntaxTree {
-    pub fn new(node: String, tree_type: TreeType, childs: Vec<Self>) -> Self {
+    pub fn new(node: String, tree_type: TreeType, childs: Vec<Self>, tree_val_type: TreeValueType) -> Self {
         Self {
             childs,
             node,
             tree_type,
+            tree_val_type,
         }
     }
 
